import { Award, Shield, Home } from "lucide-react";
import { Link } from "wouter";
import OptimizedImage from "./OptimizedImage";

export default function Hero() {

  return (
    <section id="home" className="pt-16 bg-gradient-to-br from-ta-light-gray to-white min-h-screen relative overflow-hidden" role="banner" aria-labelledby="hero-heading">
      {/* Decorative dots */}
      <div className="absolute top-20 left-20 w-4 h-4 bg-ta-teal rounded-full opacity-70"></div>
      <div className="absolute top-40 right-32 w-3 h-3 bg-ta-purple rounded-full opacity-70"></div>
      <div className="absolute bottom-40 left-1/4 w-5 h-5 bg-ta-yellow rounded-full opacity-70"></div>
      <div className="absolute bottom-60 right-20 w-4 h-4 bg-ta-green rounded-full opacity-70"></div>
      <div className="absolute top-1/3 left-12 w-3 h-3 bg-ta-orange rounded-full opacity-70"></div>
      <div className="absolute bottom-20 right-1/3 w-4 h-4 bg-ta-red rounded-full opacity-70"></div>

      <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8 py-12 sm:py-16 lg:py-20">
        <div className="grid lg:grid-cols-2 gap-8 lg:gap-12 items-center">
          <div className="space-y-8 text-center lg:text-left">
            {/* Top tagline */}
            <div className="mb-6">
              <h2 className="text-xl md:text-2xl font-semibold mb-2">
                <span className="text-ta-teal">Learn</span>{" "}
                <span className="text-ta-purple">Share</span>{" "}
                <span className="text-ta-red">Laugh</span>{" "}
                <span className="text-ta-orange">Grow</span>
              </h2>
              <p className="text-ta-text-dark text-sm animate-magic-text">Creating magical moments every day</p>
            </div>

            <div className="space-y-4">
              <h1 id="hero-heading" className="text-4xl md:text-5xl lg:text-6xl font-bold text-ta-text-dark leading-tight">
                Family Home Daycare Has The{" "}
                <span className="text-ta-orange">Feel of a Home</span>
              </h1>
              
              {/* Mobile logo - shows only on mobile below the heading */}
              <div className="lg:hidden relative flex justify-center items-center mt-8 mb-8">
                {/* Animated rainbow circle border - larger for mobile */}
                <div className="relative w-80 h-80 sm:w-96 sm:h-96 rounded-full p-1 animate-rainbow-rotate">
                  {/* Inner white circle containing the logo */}
                  <div className="w-full h-full bg-white rounded-full shadow-2xl flex items-center justify-center relative">
                    {/* Hero logo - stationary and larger */}
                    <OptimizedImage
                      src="/logo.jpg"
                      alt="Tiny Acorns Learn Share Laugh Grow"
                      width={320}
                      height={320}
                      className="w-[90%] h-[102%] object-contain rounded-full"
                      priority={true}
                    />
                  </div>
                </div>
              </div>
              
              <p className="text-lg md:text-xl text-ta-text-dark leading-relaxed">
                We strive to provide a clean, safe and educational environment for young children and their families. Within our care, children develop skills that promote physical, emotional, social and intellectual growth.
              </p>
            </div>

            {/* CTA Buttons */}
            <div className="flex flex-col sm:flex-row gap-4">
              <Link href="/enrollment">
                <button className="bg-ta-orange text-white px-8 py-4 rounded-full text-lg font-semibold hover:bg-ta-orange/90 transform hover:scale-105 transition-all duration-200 shadow-lg w-full sm:w-auto">
                  Start Enrollment
                </button>
              </Link>
              <Link href="/contact">
                <button className="bg-ta-teal text-white px-8 py-4 rounded-full text-lg font-semibold hover:bg-ta-teal/90 transform hover:scale-105 transition-all duration-200 shadow-lg w-full sm:w-auto">
                  Schedule Tour
                </button>
              </Link>
            </div>

            {/* Badges - Responsive Layout */}
            <div className="space-y-2">
              {/* Mobile: Two badges on top row */}
              <div className="flex justify-center lg:justify-start gap-2 sm:hidden">
                <div className="bg-ta-orange text-white px-2 py-1.5 rounded-full text-xs font-medium flex items-center whitespace-nowrap">
                  <Award className="w-3 h-3 mr-1" />
                  Licensed
                </div>
                <div className="bg-ta-teal text-white px-2 py-1.5 rounded-full text-xs font-medium flex items-center whitespace-nowrap">
                  <Shield className="w-3 h-3 mr-1" />
                  Safe & Secure
                </div>
              </div>
              {/* Mobile: Family Owned centered on second row */}
              <div className="flex justify-center lg:justify-start sm:hidden">
                <div className="bg-ta-purple text-white px-2 py-1.5 rounded-full text-xs font-medium flex items-center whitespace-nowrap">
                  <Home className="w-3 h-3 mr-1" />
                  Family Owned
                </div>
              </div>
              
              {/* Desktop and larger mobile: All three on one line */}
              <div className="hidden sm:flex justify-center lg:justify-start gap-3">
                <div className="bg-ta-orange text-white px-3 py-2 rounded-full text-sm font-medium flex items-center whitespace-nowrap">
                  <Award className="w-4 h-4 mr-2" />
                  Licensed
                </div>
                <div className="bg-ta-teal text-white px-3 py-2 rounded-full text-sm font-medium flex items-center whitespace-nowrap">
                  <Shield className="w-4 h-4 mr-2" />
                  Safe & Secure
                </div>
                <div className="bg-ta-purple text-white px-3 py-2 rounded-full text-sm font-medium flex items-center whitespace-nowrap">
                  <Home className="w-4 h-4 mr-2" />
                  Family Owned
                </div>
              </div>
            </div>
          </div>

          {/* Desktop logo - shows only on desktop */}
          <div className="hidden lg:flex relative justify-center items-center">
            {/* Animated rainbow circle border - larger for desktop */}
            <div className="relative w-[30rem] h-[30rem] xl:w-[38rem] xl:h-[38rem] rounded-full p-1 animate-rainbow-rotate">
              {/* Inner white circle containing the logo */}
              <div className="w-full h-full bg-white rounded-full shadow-2xl flex items-center justify-center relative">
                <img
                  src="/logo.jpg"
                  alt="Tiny Acorns Learn Share Laugh Grow - Licensed Family Home Daycare"
                  width={480}
                  height={480}
                  className="w-[90%] h-[100%] object-contain rounded-full"
                  loading="eager"
                />
              </div>
            </div>
          </div>
        </div>
      </div>
    </section>
  );
}
